/* -*- Mode: IDL; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 2 -*-
 *
 * The contents of this file are subject to the Mozilla Public
 * License Version 1.1 (the "License"); you may not use this file
 * except in compliance with the License. You may obtain a copy of
 * the License at http://www.mozilla.org/MPL/
 * 
 * Software distributed under the License is distributed on an "AS
 * IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or
 * implied. See the License for the specific language governing
 * rights and limitations under the License.
 * 
 * The Original Code is the Mozilla browser.
 * 
 * The Initial Developer of the Original Code is Netscape
 * Communications, Inc.  Portions created by Netscape are
 * Copyright (C) 1999, Mozilla.  All Rights Reserved.
 * 
 * Contributor(s):
 *   Travis Bogard <travis@netscape.com>
 */

#include "nsISupports.idl"

/**
 * The nsIXULBrowserWindow supplies the methods that may be called from the
 * internals of the browser area to tell the containing xul window to update
 * it's ui. 
 */

interface nsIRequest;

[scriptable, uuid(46B4015C-0121-11d4-9877-00C04FA0D27A)]
interface nsIXULBrowserWindow : nsISupports
{
	/*
	 Sets the status according to JS' version of status.
	*/
	void setJSStatus(in wstring status);

	/*
	 Sets the default status according to JS' version of default status.
	*/
	void setJSDefaultStatus(in wstring status);

	/*
	 Tells the object implementing this function what link we are currently over.
	*/
	void setOverLink(in wstring link);
};

